==> scidart_plot-0.0.1-dev.3.tar.gz: lib/src/svg/enums/color.dart <==
class Color {
  String _value;

  Color(String value) {
    _value = value;
  }

  static final none = Color('none');
  static final aliceblue = Color('aliceblue');
  static final aqua = Color('aqua');
  static final aquamarine = Color('aquamarine');
  static final azure = Color('azure');
  static final beige = Color('beige');
  static final bisque = Color('bisque');
  static final black = Color('black');
  static final blanchedalmond = Color('blanchedalmond');
  static final blue = Color('blue');
  static final blueviolet = Color('blueviolet');
  static final brown = Color('brown');
  static final burlywood = Color('burlywood');
  static final cadetblue = Color('cadetblue');
  static final chartreuse = Color('chartreuse');
  static final chocolate = Color('chocolate');
  static final coral = Color('coral');
  static final cornflowerblue = Color('cornflowerblue');
  static final cornsilk = Color('cornsilk');
  static final crimson = Color('crimson');
  static final cyan = Color('cyan');
  static final darkblue = Color('darkblue');
  static final darkcyan = Color('darkcyan');
  static final darkgoldenrod = Color('darkgoldenrod');
  static final darkgray = Color('darkgray');
  static final darkgreen = Color('darkgreen');
  static final darkgrey = Color('darkgrey');
  static final darkkhaki = Color('darkkhaki');
  static final darkmagenta = Color('darkmagenta');
  static final darkolivegreen = Color('darkolivegreen');
  static final darkorange = Color('darkorange');
  static final darkorchid = Color('darkorchid');
  static final darkred = Color('darkred');
  static final darksalmon = Color('darksalmon');
  static final darkseagreen = Color('darkseagreen');
  static final darkslateblue = Color('darkslateblue');
  static final darkslategray = Color('darkslategray');
  static final darkslategrey = Color('darkslategrey');
  static final darkturquoise = Color('darkturquoise');
  static final darkviolet = Color('darkviolet');
  static final deeppink = Color('deeppink');
  static final deepskyblue = Color('deepskyblue');
  static final dimgray = Color('dimgray');
  static final dimgrey = Color('dimgrey');
  static final dodgerblue = Color('dodgerblue');
  static final firebrick = Color('firebrick');
  static final floralwhite = Color('floralwhite');
  static final forestgreen = Color('forestgreen');
  static final fuchsia = Color('fuchsia');
  static final gainsboro = Color('gainsboro');
  static final ghostwhite = Color('ghostwhite');
  static final gold = Color('gold');
  static final goldenrod = Color('goldenrod');
  static final gray = Color('gray');
  static final green = Color('green');
  static final greenyellow = Color('greenyellow');
  static final grey = Color('grey');
  static final honeydew = Color('honeydew');
  static final hotpink = Color('hotpink');
  static final indianred = Color('indianred');
  static final indigo = Color('indigo');
  static final ivory = Color('ivory');
  static final khaki = Color('khaki');
  static final lavender = Color('lavender');
  static final lavenderblush = Color('lavenderblush');
  static final lawngreen = Color('lawngreen');
  static final lemonchiffon = Color('lemonchiffon');
  static final lightblue = Color('lightblue');
  static final lightcoral = Color('lightcoral');
  static final lightcyan = Color('lightcyan');
  static final lightgoldenrodyellow = Color('lightgoldenrodyellow');
  static final lightgray = Color('lightgray');
  static final lightgreen = Color('lightgreen');
  static final lightgrey = Color('lightgrey');
  static final lightpink = Color('lightpink');
  static final lightsalmon = Color('lightsalmon');
  static final lightseagreen = Color('lightseagreen');
  static final lightskyblue = Color('lightskyblue');
  static final lightslategray = Color('lightslategray');
  static final lightslategrey = Color('lightslategrey');
  static final lightsteelblue = Color('lightsteelblue');
  static final lightyellow = Color('lightyellow');
  static final lime = Color('lime');
  static final limegreen = Color('limegreen');
  static final linen = Color('linen');
  static final magenta = Color('magenta');
  static final maroon = Color('maroon');
  static final mediumaquamarine = Color('mediumaquamarine');
  static final mediumblue = Color('mediumblue');
  static final mediumorchid = Color('mediumorchid');
  static final mediumpurple = Color('mediumpurple');
  static final mediumseagreen = Color('mediumseagreen');
  static final mediumslateblue = Color('mediumslateblue');
  static final mediumspringgreen = Color('mediumspringgreen');
  static final mediumturquoise = Color('mediumturquoise');
  static final mediumvioletred = Color('mediumvioletred');
  static final midnightblue = Color('midnightblue');
  static final mintcream = Color('mintcream');
  static final mistyrose = Color('mistyrose');
  static final moccasin = Color('moccasin');
  static final navajowhite = Color('navajowhite');
  static final navy = Color('navy');
  static final oldlace = Color('oldlace');
  static final olive = Color('olive');
  static final olivedrab = Color('olivedrab');
  static final orange = Color('orange');
  static final orangered = Color('orangered');
  static final orchid = Color('orchid');
  static final palegoldenrod = Color('palegoldenrod');
  static final palegreen = Color('palegreen');
  static final paleturquoise = Color('paleturquoise');
  static final palevioletred = Color('palevioletred');
  static final papayawhip = Color('papayawhip');
  static final peachpuff = Color('peachpuff');
  static final peru = Color('peru');
  static final pink = Color('pink');
  static final plum = Color('plum');
  static final powderblue = Color('powderblue');
  static final purple = Color('purple');
  static final red = Color('red');
  static final rosybrown = Color('rosybrown');
  static final royalblue = Color('royalblue');
  static final saddlebrown = Color('saddlebrown');
  static final salmon = Color('salmon');
  static final sandybrown = Color('sandybrown');
  static final seagreen = Color('seagreen');
  static final seashell = Color('seashell');
  static final sienna = Color('sienna');
  static final silver = Color('silver');
  static final skyblue = Color('skyblue');
  static final slateblue = Color('slateblue');
  static final slategray = Color('slategray');
  static final slategrey = Color('slategrey');
  static final snow = Color('snow');
  static final springgreen = Color('springgreen');
  static final steelblue = Color('steelblue');
  static final tan = Color('tan');
  static final teal = Color('teal');
  static final thistle = Color('thistle');
  static final tomato = Color('tomato');
  static final turquoise = Color('turquoise');
  static final violet = Color('violet');
  static final wheat = Color('wheat');
  static final white = Color('white');
  static final whitesmoke = Color('whitesmoke');
  static final yellow = Color('yellow');
  static final yellowgreen = Color('yellowgreen');

  static Color hex(String value) {
    return Color(value);
  }

  static Color rgb(int r, int g, int b) {
    if (r > 255 || g > 255 || b > 255) {
      throw ArgumentError('r, g and b need to be in the rage 0-255');
    }
    var rh = r.toRadixString(16).padLeft(2, '0');
    var gh = r.toRadixString(16).padLeft(2, '0');
    var bh = r.toRadixString(16).padLeft(2, '0');

    return Color(rh + gh + bh);
  }

  static String toXml(Color color) {
    var colorStr = color != null ? color._value : Color.none._value;
    try {
      int.parse(colorStr, radix: 16);
      return '#' + colorStr;
    } on FormatException {
      return colorStr;
    }
  }
}

==> scidart_plot-0.0.2-dev.1.tar.gz: lib/src/svg/enums/color.dart <==
/// SVG color enum and helper class. Make pattern and conversion easy.
class Color {
  String _value = 'none';

  Color(String value) {
    _value = value;
  }

  static final none = Color('none');
  static final aliceblue = Color('aliceblue');
  static final aqua = Color('aqua');
  static final aquamarine = Color('aquamarine');
  static final azure = Color('azure');
  static final beige = Color('beige');
  static final bisque = Color('bisque');
  static final black = Color('black');
  static final blanchedalmond = Color('blanchedalmond');
  static final blue = Color('blue');
  static final blueviolet = Color('blueviolet');
  static final brown = Color('brown');
  static final burlywood = Color('burlywood');
  static final cadetblue = Color('cadetblue');
  static final chartreuse = Color('chartreuse');
  static final chocolate = Color('chocolate');
  static final coral = Color('coral');
  static final cornflowerblue = Color('cornflowerblue');
  static final cornsilk = Color('cornsilk');
  static final crimson = Color('crimson');
  static final cyan = Color('cyan');
  static final darkblue = Color('darkblue');
  static final darkcyan = Color('darkcyan');
  static final darkgoldenrod = Color('darkgoldenrod');
  static final darkgray = Color('darkgray');
  static final darkgreen = Color('darkgreen');
  static final darkgrey = Color('darkgrey');
  static final darkkhaki = Color('darkkhaki');
  static final darkmagenta = Color('darkmagenta');
  static final darkolivegreen = Color('darkolivegreen');
  static final darkorange = Color('darkorange');
  static final darkorchid = Color('darkorchid');
  static final darkred = Color('darkred');
  static final darksalmon = Color('darksalmon');
  static final darkseagreen = Color('darkseagreen');
  static final darkslateblue = Color('darkslateblue');
  static final darkslategray = Color('darkslategray');
  static final darkslategrey = Color('darkslategrey');
  static final darkturquoise = Color('darkturquoise');
  static final darkviolet = Color('darkviolet');
  static final deeppink = Color('deeppink');
  static final deepskyblue = Color('deepskyblue');
  static final dimgray = Color('dimgray');
  static final dimgrey = Color('dimgrey');
  static final dodgerblue = Color('dodgerblue');
  static final firebrick = Color('firebrick');
  static final floralwhite = Color('floralwhite');
  static final forestgreen = Color('forestgreen');
  static final fuchsia = Color('fuchsia');
  static final gainsboro = Color('gainsboro');
  static final ghostwhite = Color('ghostwhite');
  static final gold = Color('gold');
  static final goldenrod = Color('goldenrod');
  static final gray = Color('gray');
  static final green = Color('green');
  static final greenyellow = Color('greenyellow');
  static final grey = Color('grey');
  static final honeydew = Color('honeydew');
  static final hotpink = Color('hotpink');
  static final indianred = Color('indianred');
  static final indigo = Color('indigo');
  static final ivory = Color('ivory');
  static final khaki = Color('khaki');
  static final lavender = Color('lavender');
  static final lavenderblush = Color('lavenderblush');
  static final lawngreen = Color('lawngreen');
  static final lemonchiffon = Color('lemonchiffon');
  static final lightblue = Color('lightblue');
  static final lightcoral = Color('lightcoral');
  static final lightcyan = Color('lightcyan');
  static final lightgoldenrodyellow = Color('lightgoldenrodyellow');
  static final lightgray = Color('lightgray');
  static final lightgreen = Color('lightgreen');
  static final lightgrey = Color('lightgrey');
  static final lightpink = Color('lightpink');
  static final lightsalmon = Color('lightsalmon');
  static final lightseagreen = Color('lightseagreen');
  static final lightskyblue = Color('lightskyblue');
  static final lightslategray = Color('lightslategray');
  static final lightslategrey = Color('lightslategrey');
  static final lightsteelblue = Color('lightsteelblue');
  static final lightyellow = Color('lightyellow');
  static final lime = Color('lime');
  static final limegreen = Color('limegreen');
  static final linen = Color('linen');
  static final magenta = Color('magenta');
  static final maroon = Color('maroon');
  static final mediumaquamarine = Color('mediumaquamarine');
  static final mediumblue = Color('mediumblue');
  static final mediumorchid = Color('mediumorchid');
  static final mediumpurple = Color('mediumpurple');
  static final mediumseagreen = Color('mediumseagreen');
  static final mediumslateblue = Color('mediumslateblue');
  static final mediumspringgreen = Color('mediumspringgreen');
  static final mediumturquoise = Color('mediumturquoise');
  static final mediumvioletred = Color('mediumvioletred');
  static final midnightblue = Color('midnightblue');
  static final mintcream = Color('mintcream');
  static final mistyrose = Color('mistyrose');
  static final moccasin = Color('moccasin');
  static final navajowhite = Color('navajowhite');
  static final navy = Color('navy');
  static final oldlace = Color('oldlace');
  static final olive = Color('olive');
  static final olivedrab = Color('olivedrab');
  static final orange = Color('orange');
  static final orangered = Color('orangered');
  static final orchid = Color('orchid');
  static final palegoldenrod = Color('palegoldenrod');
  static final palegreen = Color('palegreen');
  static final paleturquoise = Color('paleturquoise');
  static final palevioletred = Color('palevioletred');
  static final papayawhip = Color('papayawhip');
  static final peachpuff = Color('peachpuff');
  static final peru = Color('peru');
  static final pink = Color('pink');
  static final plum = Color('plum');
  static final powderblue = Color('powderblue');
  static final purple = Color('purple');
  static final red = Color('red');
  static final rosybrown = Color('rosybrown');
  static final royalblue = Color('royalblue');
  static final saddlebrown = Color('saddlebrown');
  static final salmon = Color('salmon');
  static final sandybrown = Color('sandybrown');
  static final seagreen = Color('seagreen');
  static final seashell = Color('seashell');
  static final sienna = Color('sienna');
  static final silver = Color('silver');
  static final skyblue = Color('skyblue');
  static final slateblue = Color('slateblue');
  static final slategray = Color('slategray');
  static final slategrey = Color('slategrey');
  static final snow = Color('snow');
  static final springgreen = Color('springgreen');
  static final steelblue = Color('steelblue');
  static final tan = Color('tan');
  static final teal = Color('teal');
  static final thistle = Color('thistle');
  static final tomato = Color('tomato');
  static final turquoise = Color('turquoise');
  static final violet = Color('violet');
  static final wheat = Color('wheat');
  static final white = Color('white');
  static final whitesmoke = Color('whitesmoke');
  static final yellow = Color('yellow');
  static final yellowgreen = Color('yellowgreen');

  static Color hex(String value) {
    return Color(value);
  }

  static Color rgb(int r, int g, int b) {
    if (r > 255 || g > 255 || b > 255) {
      throw ArgumentError('r, g and b need to be in the rage 0-255');
    }
    var rh = r.toRadixString(16).padLeft(2, '0');
    var gh = r.toRadixString(16).padLeft(2, '0');
    var bh = r.toRadixString(16).padLeft(2, '0');

    return Color(rh + gh + bh);
  }

  static String toXml(Color? color) {
    var colorStr = color != null ? color._value : Color.none._value;
    try {
      int.parse(colorStr, radix: 16);
      return '#' + colorStr;
    } on FormatException {
      return colorStr;
    }
  }
}
